Struct ScrollingText

pub struct ScrollingText<'a> { /* private fields */ }
Available on crate feature led-matrix only.
Scrolling text renderer for LED matrix displays

Implementations

Source

impl<'a> ScrollingText<'a>

pub fn new(text: &'a str, font: &'a LedFont, config: ScrollConfig) -> Self

Create a new scrolling text instance

pub fn new_default(text: &'a str, font: &'a LedFont) -> Self

Create with default configuration

pub fn get_frame(&self) -> Result<MatrixBuffer, Error>

Get the current 8x8 frame data based on the scroll offset. This returns what should be displayed on the LED matrix at the current scroll position.

pub fn step(&mut self) -> bool

Advance the scroll position by the configured step size

pub fn reset(&mut self)

Reset scroll position to the beginning

pub fn offset(&self) -> i32

Get current scroll offset